# janky

[![PyPI](https://img.shields.io/pypi/v/janky.svg)](https://pypi.org/project/janky/)
[![Tests](https://github.com/glasnt/janky/actions/workflows/test.yml/badge.svg)](https://github.com/glasnt/janky/actions/workflows/test.yml)
[![Changelog](https://img.shields.io/github/v/release/glasnt/janky?include_prereleases&label=changelog)](https://github.com/glasnt/janky/releases)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/glasnt/janky/blob/main/LICENSE)

null

## Installation

Install this library using `pip`:
```bash
pip install janky
```
## Usage

Usage instructions go here.

## Development

To contribute to this library, first checkout the code. Then create a new virtual environment:
```bash
cd janky
python -m venv venv
source venv/bin/activate
```
Now install the dependencies and test dependencies:
```bash
python -m pip install -e '.[test]'
```
To run the tests:
```bash
python -m pytest
```
